from leapp import reporting
from leapp.actors import Actor
from leapp.libraries.common import rpms
from leapp.models import InstalledRPM
from leapp.tags import FactsPhaseTag, IPUWorkflowTag
from leapp.reporting import Report

class i686Inhibit(Actor):
    """
    Checks for problematic i686 rpms that will cause a dependency related failure on upgrade.
    """

    name = 'i686inhibit'
    consumes = ()
    produces = (Report,)
    tags = (IPUWorkflowTag, FactsPhaseTag)

    def process(self):
        output = rpms.get_installed_rpms()

        result = InstalledRPM()
        with open('I686.config','r') as file:
            issuePackages = [" ".join(line.rstrip() for line in file)]
        issueList = []
        for entry in output:
            entry = entry.strip()
            if not entry:
                continue
            name, version, release, epoch, packager, arch, pgpsig = entry.split('|')
            for item in issuePackages:
                if name in item:
                    if arch == "i686":
                       issueList.append((name + '.' + arch).encode("utf-8"))
        if issueList:
            issueList = str(issueList).strip("[]")
            issueList = issueList.replace("'","")

            warnMsg = 'rpm(s) ' + issueList + ' for i686 architecture installed. This will cause dependency failure on upgrade.'
            self.log.warning(warnMsg)
            reporting.create_report(
                    [
                        reporting.Title("Problematic i686 rpms installed"),
                        reporting.Summary(warnMsg),
                        reporting.Severity(reporting.Severity.HIGH),
                        reporting.Groups([reporting.Groups.REPOSITORY]),
                        reporting.Groups([reporting.Groups.INHIBITOR]),
                        reporting.Remediation(
                            hint=(
                                "Please run command #yum remove for all conflicting packages before upgrade, e.g. #sudo yum remove -y " + issueList.replace(",","")
                            )
                        ),
                    ]
                )
